@@ -1,10 +1,11 @@
-from typing import Optional, List, Dict, Any
+from typing import Any, Dict, List, Optional
 
 import pandas as pd
 import plotly.graph_objects as go
 
 from webviz_subsurface._abbreviations.number_formatting import si_prefixed
 from webviz_subsurface._utils.formatting import printable_int_list
+
 from ._tornado_data import TornadoData
 
 
@@ -256,7 +257,7 @@ class TornadoBarChart:
         return _layout
 
     @property
-    def figure(self) -> Dict:
+    def figure(self) -> go.Figure:
         data = self.data
 
         fig = go.Figure({"data": data, "layout": self.layout})
