@@ -1,10 +1,17 @@
-from typing import List, Optional, Dict, Any
+from typing import Any, Dict, List, Optional
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 
-from ._processing import interpolate_depth, filter_frame
-from ..._utils.colors import hex_to_rgba
+from ..._utils.fanchart_plotting import (
+    FanchartData,
+    FreeLineData,
+    LowHighData,
+    MinMaxData,
+    TraceDirection,
+    get_fanchart_traces,
+)
+from ._processing import filter_frame, interpolate_depth
 
 
 class FormationFigure:
@@ -265,7 +272,7 @@ class FormationFigure:
                     dframes["maximum"] = dframe.max()
                     dframes["minimum"] = dframe.min()
                     self.traces.extend(
-                        add_fanchart_traces(
+                        _get_fanchart_traces(
                             pd.concat(dframes, names=["STATISTIC"], sort=False)[
                                 "PRESSURE"
                             ],
@@ -275,69 +282,32 @@ class FormationFigure:
                     )
 
 
-def add_fanchart_traces(
+def _get_fanchart_traces(
     vector_stats: pd.DataFrame, color: str, legend_group: str
 ) -> List[Dict[str, Any]]:
     """Renders a fanchart for an ensemble vector"""
-    fill_color = hex_to_rgba(color, 0.3)
-    line_color = hex_to_rgba(color, 1)
-    return [
-        {
-            "name": legend_group,
-            "hovertext": "Maximum",
-            "y": vector_stats["maximum"].index.tolist(),
-            "x": vector_stats["maximum"].values,
-            "mode": "lines",
-            "line": {"width": 0, "color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "P10",
-            "y": vector_stats["p10"].index.tolist(),
-            "x": vector_stats["p10"].values,
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "Mean",
-            "y": vector_stats["mean"].index.tolist(),
-            "x": vector_stats["mean"].values,
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": True,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "P90",
-            "y": vector_stats["p90"].index.tolist(),
-            "x": vector_stats["p90"].values,
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "Minimum",
-            "y": vector_stats["minimum"].index.tolist(),
-            "x": vector_stats["minimum"].values,
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-    ]
+
+    # Retrieve indices from one of the keys
+    x = vector_stats["maximum"].index.tolist()
+
+    data = FanchartData(
+        samples=x,
+        low_high=LowHighData(
+            low_data=vector_stats["p90"].values,
+            low_name="P90",
+            high_data=vector_stats["p10"].values,
+            high_name="P10",
+        ),
+        minimum_maximum=MinMaxData(
+            minimum=vector_stats["minimum"].values,
+            maximum=vector_stats["maximum"].values,
+        ),
+        free_line=FreeLineData("Mean", vector_stats["mean"].values),
+    )
+
+    return get_fanchart_traces(
+        data=data,
+        color=color,
+        legend_group=legend_group,
+        direction=TraceDirection.VERTICAL,
+    )
