@@ -1,44 +1,50 @@
-from typing import Callable, Optional, Any
+from typing import Any, Callable, Optional
 
-import dash
-from dash.dependencies import Input, Output, State, ALL
-from dash.exceptions import PreventUpdate
 import webviz_core_components as wcc
+from dash import ALL, Dash, Input, Output, State, callback_context, no_update
+from dash.exceptions import PreventUpdate
+
 from webviz_subsurface._models import InplaceVolumesModel
+
 from ..utils.utils import create_range_string, update_relevant_components
 
 
-# pylint: disable=too-many-statements, too-many-locals, too-many-arguments
+# pylint: disable=too-many-statements,too-many-arguments
 def selections_controllers(
-    app: dash.Dash, get_uuid: Callable, volumemodel: InplaceVolumesModel
+    app: Dash, get_uuid: Callable, volumemodel: InplaceVolumesModel
 ) -> None:
     @app.callback(
         Output(get_uuid("selections"), "data"),
         Input({"id": get_uuid("selections"), "tab": ALL, "selector": ALL}, "value"),
-        Input({"id": get_uuid("filters"), "tab": ALL, "selector": ALL}, "value"),
+        Input(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": ALL},
+            "value",
+        ),
         Input(
             {"id": get_uuid("selections"), "tab": "voldist", "settings": "Colorscale"},
             "colorscale",
         ),
+        Input(get_uuid("initial-load-info"), "data"),
         State(get_uuid("page-selected"), "data"),
         State(get_uuid("tabs"), "value"),
         State(get_uuid("selections"), "data"),
-        State(get_uuid("initial-load-info"), "data"),
         State({"id": get_uuid("selections"), "tab": ALL, "selector": ALL}, "id"),
-        State({"id": get_uuid("filters"), "tab": ALL, "selector": ALL}, "id"),
+        State(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": ALL}, "id"
+        ),
     )
     def _update_selections(
         selectors: list,
         filters: list,
         colorscale: str,
+        initial_load: dict,
         selected_page: str,
         selected_tab: str,
         previous_selection: dict,
-        initial_load: dict,
         selector_ids: list,
         filter_ids: list,
     ) -> dict:
-        ctx = dash.callback_context.triggered[0]
+        ctx = callback_context.triggered[0]
         if ctx["prop_id"] == ".":
             raise PreventUpdate
 
@@ -127,7 +133,7 @@ def selections_controllers(
         previous_selection: Optional[dict],
         selected_tab: str,
     ) -> tuple:
-        ctx = dash.callback_context.triggered[0]
+        ctx = callback_context.triggered[0]
         if (
             selected_tab != "voldist"
             or ("Color by" in ctx["prop_id"] and plot_type not in ["box", "bar"])
@@ -208,7 +214,7 @@ def selections_controllers(
                 id_list=selector_ids,
                 update_info=[
                     {
-                        "new_value": values.get(prop, dash.no_update),
+                        "new_value": values.get(prop, no_update),
                         "conditions": {"selector": selector},
                     }
                     for selector, values in settings.items()
@@ -218,33 +224,39 @@ def selections_controllers(
         )
 
     @app.callback(
-        Output({"id": get_uuid("filters"), "tab": ALL, "selector": ALL}, "multi"),
-        Output({"id": get_uuid("filters"), "tab": ALL, "selector": ALL}, "value"),
         Output(
-            {"id": get_uuid("filters"), "tab": ALL, "element": "real_text"}, "children"
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": "undef"},
+            "multi",
+        ),
+        Output(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": "undef"},
+            "value",
         ),
         Input(get_uuid("page-selected"), "data"),
         Input({"id": get_uuid("selections"), "tab": ALL, "selector": ALL}, "value"),
-        Input({"id": get_uuid("filters"), "tab": ALL, "component_type": ALL}, "value"),
         State({"id": get_uuid("selections"), "tab": ALL, "selector": ALL}, "id"),
         State(get_uuid("tabs"), "value"),
-        State({"id": get_uuid("filters"), "tab": ALL, "selector": ALL}, "options"),
-        State({"id": get_uuid("filters"), "tab": ALL, "selector": ALL}, "multi"),
-        State({"id": get_uuid("filters"), "tab": ALL, "selector": ALL}, "id"),
-        State({"id": get_uuid("filters"), "tab": ALL, "component_type": ALL}, "id"),
-        State({"id": get_uuid("filters"), "tab": ALL, "element": "real_text"}, "id"),
+        State(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": "undef"},
+            "options",
+        ),
+        State(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": "undef"},
+            "multi",
+        ),
+        State(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": "undef"},
+            "id",
+        ),
     )
     def _update_filter_options(
         _selected_page: str,
         selectors: list,
-        reals: list,
         selector_ids: list,
         selected_tab: str,
         filter_options: list,
         filter_multi: list,
         filter_ids: list,
-        reals_ids: list,
-        real_string_ids: list,
     ) -> tuple:
 
         page_selections = {
@@ -268,17 +280,26 @@ def selections_controllers(
             ]
         if selected_tab == "table" and page_selections["Group by"] is not None:
             selected_data = page_selections["Group by"]
+        if selected_tab == "tornado":
+            selected_data = ["SENSNAME"]
 
         output = {}
-        for selector in ["SOURCE", "ENSEMBLE"]:
+        for selector in ["SOURCE", "ENSEMBLE", "SENSNAME"]:
+            if selector not in page_filter_settings:
+                continue
+            options = [x["value"] for x in page_filter_settings[selector]["options"]]
             multi = selector in selected_data
             selector_is_multi = page_filter_settings[selector]["multi"]
             if not multi and selector_is_multi:
-                values = [page_filter_settings[selector]["options"][0]["value"]]
+                values = [
+                    "rms_seed"
+                    if selector == "SENSNAME" and "rms_seed" in options
+                    else options[0]
+                ]
             elif multi and not selector_is_multi:
-                values = [x["value"] for x in page_filter_settings[selector]["options"]]
+                values = options
             else:
-                multi = values = dash.no_update
+                multi = values = no_update
             output[selector] = {"multi": multi, "values": values}
 
         # filter tornado on correct fluid based on volume response chosen
@@ -290,24 +311,12 @@ def selections_controllers(
                 ]
             }
 
-        # realization
-        index = [x["tab"] for x in reals_ids].index(selected_tab)
-        real_list = [int(real) for real in reals[index]]
-
-        if reals_ids[index]["component_type"] == "range":
-            real_list = list(range(real_list[0], real_list[1] + 1))
-            text = f"{real_list[0]}-{real_list[-1]}"
-        else:
-            text = create_range_string(real_list)
-
-        output["REAL"] = {"values": real_list}
-
         return (
             update_relevant_components(
                 id_list=filter_ids,
                 update_info=[
                     {
-                        "new_value": values.get("multi", dash.no_update),
+                        "new_value": values.get("multi", no_update),
                         "conditions": {"tab": selected_tab, "selector": selector},
                     }
                     for selector, values in output.items()
@@ -317,12 +326,58 @@ def selections_controllers(
                 id_list=filter_ids,
                 update_info=[
                     {
-                        "new_value": values.get("values", dash.no_update),
+                        "new_value": values.get("values", no_update),
                         "conditions": {"tab": selected_tab, "selector": selector},
                     }
                     for selector, values in output.items()
                 ],
             ),
+        )
+
+    @app.callback(
+        Output(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": "REAL"},
+            "value",
+        ),
+        Output(
+            {"id": get_uuid("filters"), "tab": ALL, "element": "real_text"}, "children"
+        ),
+        Input({"id": get_uuid("filters"), "tab": ALL, "component_type": ALL}, "value"),
+        State(get_uuid("tabs"), "value"),
+        State({"id": get_uuid("filters"), "tab": ALL, "component_type": ALL}, "id"),
+        State({"id": get_uuid("filters"), "tab": ALL, "element": "real_text"}, "id"),
+        State(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": "REAL"},
+            "id",
+        ),
+    )
+    def _update_realization_filter_and_text(
+        reals: list,
+        selected_tab: str,
+        reals_ids: list,
+        real_string_ids: list,
+        real_filter_id: list,
+    ) -> tuple:
+        """Callback that updates the selected relization info and text"""
+        if selected_tab == "fipqc":
+            raise PreventUpdate
+
+        index = [x["tab"] for x in reals_ids].index(selected_tab)
+        real_list = [int(real) for real in reals[index]]
+
+        if reals_ids[index]["component_type"] == "range":
+            real_list = list(range(real_list[0], real_list[1] + 1))
+            text = f"{real_list[0]}-{real_list[-1]}"
+        else:
+            text = create_range_string(real_list)
+
+        return (
+            update_relevant_components(
+                id_list=real_filter_id,
+                update_info=[
+                    {"new_value": real_list, "conditions": {"tab": selected_tab}}
+                ],
+            ),
             update_relevant_components(
                 id_list=real_string_ids,
                 update_info=[{"new_value": text, "conditions": {"tab": selected_tab}}],
@@ -374,67 +429,49 @@ def selections_controllers(
         input_ids: list,
         wrapper_ids: list,
     ) -> list:
+        if selected_tab == "fipqc":
+            raise PreventUpdate
+
         reals = volumemodel.realizations
         prev_selection = (
             selections[selected_page]["filters"].get("REAL", [])
             if selections is not None and selected_page in selections
             else None
         )
-
-        page_value = [
+        selected_component = [
             value
             for id_value, value in zip(input_ids, input_selectors)
             if id_value["tab"] == selected_tab
-        ]
+        ][0]
+        selected_reals = prev_selection if prev_selection is not None else reals
 
-        if page_value[0] == "range":
-            min_value = (
-                min(prev_selection) if prev_selection is not None else min(reals)
+        component = (
+            wcc.RangeSlider(
+                id={
+                    "id": get_uuid("filters"),
+                    "tab": selected_tab,
+                    "component_type": selected_component,
+                },
+                value=[min(selected_reals), max(selected_reals)],
+                min=min(reals),
+                max=max(reals),
+                marks={str(i): {"label": str(i)} for i in [min(reals), max(reals)]},
             )
-            max_value = (
-                max(prev_selection) if prev_selection is not None else max(reals)
+            if selected_component == "range"
+            else wcc.SelectWithLabel(
+                id={
+                    "id": get_uuid("filters"),
+                    "tab": selected_tab,
+                    "component_type": selected_component,
+                },
+                options=[{"label": i, "value": i} for i in reals],
+                value=selected_reals,
+                size=min(20, len(reals)),
             )
-            return update_relevant_components(
-                id_list=wrapper_ids,
-                update_info=[
-                    {
-                        "new_value": wcc.RangeSlider(
-                            id={
-                                "id": get_uuid("filters"),
-                                "tab": selected_tab,
-                                "component_type": page_value[0],
-                            },
-                            value=[min_value, max_value],
-                            min=min(reals),
-                            max=max(reals),
-                            marks={
-                                str(i): {"label": str(i)}
-                                for i in [min(reals), max(reals)]
-                            },
-                        ),
-                        "conditions": {"tab": selected_tab},
-                    }
-                ],
-            )
-
-        # if input_selector == "select"
+        )
         return update_relevant_components(
             id_list=wrapper_ids,
-            update_info=[
-                {
-                    "new_value": wcc.SelectWithLabel(
-                        id={
-                            "id": get_uuid("filters"),
-                            "tab": selected_tab,
-                            "component_type": page_value[0],
-                        },
-                        options=[{"label": i, "value": i} for i in reals],
-                        value=prev_selection if prev_selection is not None else reals,
-                        size=min(20, len(reals)),
-                    ),
-                    "conditions": {"tab": selected_tab},
-                }
-            ],
+            update_info=[{"new_value": component, "conditions": {"tab": selected_tab}}],
         )
 
     @app.callback(
@@ -457,8 +494,9 @@ def selections_controllers(
     def _update_tornado_selections_from_mode(mode: str, selector_ids: list) -> tuple:
         settings = {}
         if mode == "custom":
+            responses = [x for x in volumemodel.responses if x not in ["BO", "BG"]]
             settings["Response left"] = settings["Response right"] = {
-                "options": [{"label": i, "value": i} for i in volumemodel.responses],
+                "options": [{"label": i, "value": i} for i in responses],
                 "disabled": False,
             }
         else:
@@ -481,7 +519,7 @@ def selections_controllers(
                 id_list=selector_ids,
                 update_info=[
                     {
-                        "new_value": values.get(prop, dash.no_update),
+                        "new_value": values.get(prop, no_update),
                         "conditions": {"selector": selector},
                     }
                     for selector, values in settings.items()
@@ -489,3 +527,127 @@ def selections_controllers(
             )
             for prop in ["options", "value", "disabled"]
         )
+
+    @app.callback(
+        Output(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": "region"},
+            "value",
+        ),
+        Output(
+            {"id": get_uuid("filters"), "wrapper": ALL, "tab": ALL, "type": "region"},
+            "style",
+        ),
+        Input(
+            {"id": get_uuid("filters"), "tab": ALL, "element": "region-selector"},
+            "value",
+        ),
+        State(
+            {"id": get_uuid("filters"), "tab": ALL, "selector": ALL, "type": "region"},
+            "id",
+        ),
+        State(get_uuid("tabs"), "value"),
+        State(get_uuid("page-selected"), "data"),
+        State(get_uuid("selections"), "data"),
+        State(
+            {"id": get_uuid("filters"), "wrapper": ALL, "tab": ALL, "type": "region"},
+            "id",
+        ),
+        State(
+            {"id": get_uuid("filters"), "tab": ALL, "element": "region-selector"},
+            "id",
+        ),
+        prevent_initial_call=True,
+    )
+    def update_region_filters(
+        selected_reg_filter: list,
+        reg_filter_ids: list,
+        selected_tab: str,
+        selected_page: str,
+        selections: dict,
+        wrapper_ids: list,
+        reg_select_ids: list,
+    ) -> tuple:
+        """
+        Callback to update the visible region filter between FIPNUM or ZONE/REGION.
+        When changing, the active selection will be used to set the new selection.
+        Note this callback will only be used for cases where each FIPNUM belongs to
+        a unique ZONE and REGION.
+        """
+        selected = [
+            value
+            for id_value, value in zip(reg_select_ids, selected_reg_filter)
+            if id_value["tab"] == selected_tab
+        ]
+
+        df = volumemodel.dataframe
+        filters = selections[selected_page]["filters"]
+
+        values = {}
+        if selected[0] != "fipnum":
+            values["FIPNUM"] = df["FIPNUM"].unique()
+            for elm in ["REGION", "ZONE"]:
+                values[elm] = df.loc[df["FIPNUM"].isin(filters["FIPNUM"])][elm].unique()
+
+        else:
+            values["REGION"] = df["REGION"].unique()
+            values["ZONE"] = df["ZONE"].unique()
+            mask = (df["REGION"].isin(filters["REGION"])) & (
+                df["ZONE"].isin(filters["ZONE"])
+            )
+            values["FIPNUM"] = df.loc[mask]["FIPNUM"].unique()
+
+        styles = {}
+        styles["FIPNUM"] = {"display": "none" if selected[0] != "fipnum" else "block"}
+        styles["REGION"] = {"display": "none" if selected[0] == "fipnum" else "block"}
+        styles["ZONE"] = {"display": "none" if selected[0] == "fipnum" else "block"}
+
+        return (
+            update_relevant_components(
+                id_list=reg_filter_ids,
+                update_info=[
+                    {
+                        "new_value": value,
+                        "conditions": {"selector": selector, "tab": selected_tab},
+                    }
+                    for selector, value in values.items()
+                ],
+            ),
+            update_relevant_components(
+                id_list=wrapper_ids,
+                update_info=[
+                    {
+                        "new_value": style,
+                        "conditions": {"wrapper": selector, "tab": selected_tab},
+                    }
+                    for selector, style in styles.items()
+                ],
+            ),
+        )
+
+    @app.callback(
+        Output(
+            {"id": get_uuid("selections"), "tab": "src-comp", "selector": "Ignore <"},
+            "value",
+        ),
+        Input(
+            {"id": get_uuid("selections"), "tab": "src-comp", "selector": "Response"},
+            "value",
+        ),
+    )
+    def _reset_ignore_value_source_comparison(_response_change: str) -> float:
+        """reset ignore value when new response is selected"""
+        return 0
+
+    @app.callback(
+        Output(
+            {"id": get_uuid("selections"), "tab": "ens-comp", "selector": "Ignore <"},
+            "value",
+        ),
+        Input(
+            {"id": get_uuid("selections"), "tab": "ens-comp", "selector": "Response"},
+            "value",
+        ),
+    )
+    def _reset_ignore_value_ens_comparison(_response_change: str) -> float:
+        """reset ignore value when new response is selected"""
+        return 0
