@@ -1,4 +1,5 @@
 from typing import List
+
 import dash
 
 
@@ -13,7 +14,7 @@ def create_range_string(real_list: list) -> str:
             idx += 1
 
     return ", ".join(
-        map(lambda p: "%s-%s" % tuple(p) if p[0] != p[1] else str(p[0]), ranges)
+        map(lambda p: f"{p[0]}-{p[1]}" if p[0] != p[1] else str(p[0]), ranges)
     )
 
 
@@ -25,3 +26,7 @@ def update_relevant_components(id_list: list, update_info: List[dict]) -> list:
                 output_id_list[idx] = elm["new_value"]
                 break
     return output_id_list
+
+
+def move_to_end_of_list(element: str, list_of_elements: list) -> list:
+    return [x for x in list_of_elements if x != element] + [element]
