@@ -1,7 +1,9 @@
 from typing import List, Optional
-import dash_html_components as html
+
 import webviz_core_components as wcc
+from dash import html
 from webviz_config import WebvizConfigTheme
+
 from webviz_subsurface._models import InplaceVolumesModel
 
 
@@ -11,19 +13,28 @@ def selections_layout(
     theme: WebvizConfigTheme,
     tab: str,
 ) -> html.Div:
-    """Layout for selecting intersection data"""
     selectors = "/".join(
-        [x.lower() for x in ["ZONE", "REGION", "FACIES"] if x in volumemodel.selectors]
+        [
+            x.lower()
+            for x in ["ZONE", "REGION", "FACIES", "FIPNUM", "SET"]
+            if x in volumemodel.selectors
+        ]
     )
     return html.Div(
         children=[
-            button(uuid=uuid, title="1 plot / 1 table", page_id="1p1t"),
-            button(uuid=uuid, title=f"Plots per {selectors}", page_id="per_zr"),
-            button(uuid=uuid, title="Convergence plot mean/p10/p90", page_id="conv"),
-            button(uuid=uuid, title="Custom plotting", page_id="custom"),
+            html.Div(
+                style={"margin-bottom": "20px"},
+                children=[
+                    button(uuid=uuid, title="1 plot / 1 table", page_id="1p1t"),
+                    button(uuid=uuid, title=f"Plots per {selectors}", page_id="per_zr"),
+                    button(
+                        uuid=uuid, title="Convergence plot mean/p10/p90", page_id="conv"
+                    ),
+                    button(uuid=uuid, title="Custom plotting", page_id="custom"),
+                ],
+            ),
             plot_selections_layout(uuid, volumemodel, tab),
-            table_selections_layout(uuid, volumemodel, tab),
-            settings_layout(uuid, theme, tab),
+            settings_layout(volumemodel, uuid, theme, tab),
         ]
     )
 
@@ -42,7 +53,7 @@ def button(
 
 def plot_selections_layout(
     uuid: str, volumemodel: InplaceVolumesModel, tab: str
-) -> html.Details:
+) -> wcc.Selectors:
     return wcc.Selectors(
         label="PLOT CONTROLS",
         open_details=True,
@@ -52,13 +63,12 @@ def plot_selections_layout(
 
 def table_selections_layout(
     uuid: str, volumemodel: InplaceVolumesModel, tab: str
-) -> html.Details:
+) -> wcc.Selectors:
     responses = volumemodel.volume_columns + volumemodel.property_columns
     return wcc.Selectors(
         label="TABLE CONTROLS",
         open_details=True,
         children=[
-            table_sync_option(uuid, tab),
             wcc.Dropdown(
                 label="Table type",
                 id={"id": uuid, "tab": tab, "selector": "Table type"},
@@ -66,43 +76,30 @@ def table_selections_layout(
                     {"label": elm, "value": elm}
                     for elm in ["Statistics table", "Mean table"]
                 ],
-                value="Statistics table",
+                value="Mean table",
                 clearable=False,
             ),
-            html.Div(
+            wcc.Dropdown(
+                label="Group by",
+                id={"id": uuid, "tab": tab, "selector": "Group by"},
+                options=[{"label": elm, "value": elm} for elm in volumemodel.selectors],
+                value=None,
+                multi=True,
+                clearable=False,
+            ),
+            wcc.SelectWithLabel(
+                label="Responses",
                 id={
                     "id": uuid,
                     "tab": tab,
-                    "element": "table_response_group_wrapper",
+                    "selector": "table_responses",
                 },
-                style={"display": "None"},
-                children=[
-                    wcc.Dropdown(
-                        label="Group by",
-                        id={"id": uuid, "tab": tab, "selector": "Group by"},
-                        options=[
-                            {"label": elm, "value": elm}
-                            for elm in volumemodel.selectors
-                        ],
-                        value=None,
-                        multi=True,
-                        clearable=False,
-                    ),
-                    wcc.SelectWithLabel(
-                        label="Responses",
-                        id={
-                            "id": uuid,
-                            "tab": tab,
-                            "selector": "table_responses",
-                        },
-                        options=[{"label": i, "value": i} for i in responses],
-                        value=responses,
-                        size=min(
-                            20,
-                            len(responses),
-                        ),
-                    ),
-                ],
+                options=[{"label": i, "value": i} for i in responses],
+                value=responses,
+                size=min(
+                    20,
+                    len(responses),
+                ),
             ),
         ],
     )
@@ -153,14 +150,16 @@ def plot_selector_dropdowns(
     return dropdowns
 
 
-def settings_layout(uuid: str, theme: WebvizConfigTheme, tab: str) -> wcc.Selectors:
+def settings_layout(
+    volumemodel: InplaceVolumesModel, uuid: str, theme: WebvizConfigTheme, tab: str
+) -> wcc.Selectors:
 
     theme_colors = theme.plotly_theme.get("layout", {}).get("colorway", [])
     return wcc.Selectors(
         label="⚙️ SETTINGS",
         open_details=False,
         children=[
-            remove_fluid_annotation(uuid=uuid, tab=tab),
+            remove_fluid_annotation(volumemodel, uuid=uuid, tab=tab),
             subplot_xaxis_range(uuid=uuid, tab=tab),
             histogram_options(uuid=uuid, tab=tab),
             html.Span("Colors", style={"font-weight": "bold"}),
@@ -205,13 +204,18 @@ def table_sync_option(uuid: str, tab: str) -> html.Div:
     )
 
 
-def remove_fluid_annotation(uuid: str, tab: str) -> html.Div:
+def remove_fluid_annotation(
+    volumemodel: InplaceVolumesModel, uuid: str, tab: str
+) -> html.Div:
     return html.Div(
-        style={"margin-bottom": "10px"},
+        style={
+            "margin-bottom": "10px",
+            "display": "none" if volumemodel.volume_type == "dynamic" else "block",
+        },
         children=wcc.Checklist(
             id={"id": uuid, "tab": tab, "selector": "Fluid annotation"},
             options=[{"label": "Show fluid annotation", "value": "Show"}],
-            value=["Show"],
+            value=["Show"] if volumemodel.volume_type != "dynamic" else [],
         ),
     )
 
