@@ -1,5 +1,6 @@
-import dash_html_components as html
 import webviz_core_components as wcc
+from dash import html
+
 from webviz_subsurface._models import InplaceVolumesModel
 
 
